@@ -41,7 +41,6 @@ __all__ = (
     "LivePreRollConfigurationTypeDef",
     "ManifestProcessingRulesTypeDef",
     "PlaybackConfigurationTypeDef",
-    "ProgramTypeDef",
     "ResponseOutputItemTypeDef",
     "ScheduleEntryTypeDef",
     "SlateSourceTypeDef",
@@ -63,7 +62,6 @@ __all__ = (
     "GetPlaybackConfigurationResponseTypeDef",
     "ListChannelsResponseTypeDef",
     "ListPlaybackConfigurationsResponseTypeDef",
-    "ListProgramsResponseTypeDef",
     "ListSourceLocationsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "ListVodSourcesResponseTypeDef",
@@ -205,27 +203,6 @@ PlaybackConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredProgramTypeDef = TypedDict(
-    "_RequiredProgramTypeDef",
-    {
-        "Arn": str,
-        "ChannelName": str,
-        "ProgramName": str,
-        "SourceLocationName": str,
-        "VodSourceName": str,
-    },
-)
-_OptionalProgramTypeDef = TypedDict(
-    "_OptionalProgramTypeDef",
-    {"AdBreaks": List["AdBreakTypeDef"], "CreationTime": datetime, "LastModifiedTime": datetime},
-    total=False,
-)
-
-
-class ProgramTypeDef(_RequiredProgramTypeDef, _OptionalProgramTypeDef):
-    pass
-
-
 _RequiredResponseOutputItemTypeDef = TypedDict(
     "_RequiredResponseOutputItemTypeDef",
     {"ManifestName": str, "PlaybackUrl": str, "SourceGroup": str},
@@ -498,10 +475,6 @@ ListPlaybackConfigurationsResponseTypeDef = TypedDict(
     total=False,
 )
 
-ListProgramsResponseTypeDef = TypedDict(
-    "ListProgramsResponseTypeDef", {"Items": List["ProgramTypeDef"], "NextToken": str}, total=False
-)
-
 ListSourceLocationsResponseTypeDef = TypedDict(
     "ListSourceLocationsResponseTypeDef",
     {"Items": List["SourceLocationTypeDef"], "NextToken": str},
